/** 
 * Copyright (C) 2001-2002 the KGhostView authors. See file AUTHORS.
 * 	
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef KGVMAINWIDGET_H
#define KGVMAINWIDGET_H

#include <tqwidget.h>

class KURL;

class KGVMainWidget : public TQWidget
{
    TQ_OBJECT
  
    
public:
    KGVMainWidget( TQWidget* parent = 0, const char* name = 0 );

signals:
    void spacePressed();
    void urlDropped( const KURL& );

protected:
    virtual void keyPressEvent( TQKeyEvent* );
    virtual void dragEnterEvent( TQDragEnterEvent* );
    virtual void dropEvent( TQDropEvent* );
};

#endif
